@@ -8,11 +8,11 @@ use File::Path qw( make_path );
 use Dist::Zilla::MintingProfile::Author::Plicease;
 
 # ABSTRACT: add author only relese tests to xt/release
-our $VERSION = '0.95'; # VERSION
+our $VERSION = '0.96'; # VERSION
 
 
 with 'Dist::Zilla::Role::BeforeBuild';
-with 'Dist::Zilla::Role::BeforeRelease';
+with 'Dist::Zilla::Role::TestRunner';
 
 has source => (
   is      =>'ro',
@@ -63,15 +63,10 @@ sub before_build
   }
 }
 
-sub before_release
+sub test
 {
-  my($self) = @_;
-  
-  my $build_root = $self->zilla->built_in;
-  $self->log("prove release tests in $build_root");
-  local $CWD = $build_root;
-  system 'prove', '-lr', 'xt';
-  
+  my($self, $target) = @_;
+  system 'prove', '-br', 'xt';
   $self->log_fatal('release test failure') unless $? == 0;
 }
 
@@ -87,7 +82,7 @@ Dist::Zilla::Plugin::Author::Plicease::Tests - add author only relese tests to x
 
 =head1 VERSION
 
-version 0.95
+version 0.96
 
 =head1 SYNOPSIS
 
